@@ -18,8 +18,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-# $Id: Handle.pm,v 1.4 2001/10/24 14:40:04 rich Exp $
-
 =pod
 
 =head1 NAME
@@ -30,12 +28,8 @@ Net::FTPServer::Handle - A generic Net::FTPServer file or directory handle.
 
   use Net::FTPServer::Handle;
 
-=head1 DESCRIPTION
-
 =head1 METHODS
 
-=over 4
-
 =cut
 
 package Net::FTPServer::Handle;
@@ -43,10 +37,12 @@ package Net::FTPServer::Handle;
 use strict;
 
 use vars qw($VERSION);
-( $VERSION ) = '$Revision: 1.4 $ ' =~ /\$Revision:\s+([^\s]+)/;
+( $VERSION ) = '$Revision: 1.1 $ ' =~ /\$Revision:\s+([^\s]+)/;
 
 =pod
 
+=over 4
+
 =item $handle = Net::FTPServer::Handle->new ($ftps);
 
 Create a new handle. You would normally call this from
@@ -204,7 +200,7 @@ sub delete
 
 __END__
 
-=back 4
+=back
 
 =head1 AUTHORS
 
@@ -217,6 +213,6 @@ London, SW6 3EG, UK
 
 =head1 SEE ALSO
 
-L<Net::FTPServer(3)>, L<perl(1)>
+C<Net::FTPServer(3)>, C<perl(1)>
 
 =cut
