@@ -18,8 +18,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-# $Id: DirHandle.pm,v 1.10 2001/10/24 14:40:06 rich Exp $
-
 =pod
 
 =head1 NAME
@@ -30,12 +28,8 @@ Net::FTPServer::InMem::DirHandle - Store files in local memory
 
   use Net::FTPServer::InMem::DirHandle;
 
-=head1 DESCRIPTION
-
 =head1 METHODS
 
-=over 4
-
 =cut
 
 package Net::FTPServer::InMem::DirHandle;
@@ -43,7 +37,7 @@ package Net::FTPServer::InMem::DirHandle;
 use strict;
 
 use vars qw($VERSION);
-( $VERSION ) = '$Revision: 1.10 $ ' =~ /\$Revision:\s+([^\s]+)/;
+( $VERSION ) = '$Revision: 1.1 $ ' =~ /\$Revision:\s+([^\s]+)/;
 
 use Carp qw(confess croak);
 use IO::Scalar;
@@ -404,8 +398,6 @@ sub open
 
 __END__
 
-=back 4
-
 =head1 AUTHORS
 
 Richard Jones (rich@annexia.org).
@@ -417,6 +409,6 @@ London, SW6 3EG, UK
 
 =head1 SEE ALSO
 
-L<Net::FTPServer(3)>, L<perl(1)>
+C<Net::FTPServer(3)>, C<perl(1)>
 
 =cut
