@@ -18,8 +18,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-# $Id: DirHandle.pm,v 1.1 2003/09/28 11:50:45 rwmj Exp $
-
 =pod
 
 =head1 NAME
@@ -30,12 +28,8 @@ Net::FTPServer::RO::DirHandle - The anonymous, read-only FTP server personality
 
   use Net::FTPServer::RO::DirHandle;
 
-=head1 DESCRIPTION
-
 =head1 METHODS
 
-=over 4
-
 =cut
 
 package Net::FTPServer::RO::DirHandle;
@@ -43,7 +37,7 @@ package Net::FTPServer::RO::DirHandle;
 use strict;
 
 use vars qw($VERSION);
-( $VERSION ) = '$Revision: 1.1 $ ' =~ /\$Revision:\s+([^\s]+)/;
+( $VERSION ) = '$Revision: 1.2 $ ' =~ /\$Revision:\s+([^\s]+)/;
 
 use IO::Dir;
 use Carp qw(confess);
@@ -56,6 +50,8 @@ use vars qw(@ISA);
 
 =pod
 
+=over 4
+
 =item $handle = $dirh->get ($filename);
 
 Return the file or directory C<$handle> corresponding to
@@ -232,7 +228,7 @@ sub status
     # If the directory has been removed since we created this
     # handle, then $dev will be undefined. Return dummy status
     # information.
-    return ("d", 0000, 1, "-", "-", 0, 0) unless $dev;
+    return ("d", 0000, 1, "-", "-", 0, 0) unless defined $dev;
 
     # Generate printable user/group.
     my $user = getpwuid ($uid) || "-";
@@ -329,7 +325,7 @@ sub open
 
 __END__
 
-=back 4
+=back
 
 =head1 AUTHORS
 
@@ -342,6 +338,6 @@ London, SW6 3EG, UK
 
 =head1 SEE ALSO
 
-L<Net::FTPServer(3)>, L<perl(1)>
+C<Net::FTPServer(3)>, C<perl(1)>
 
 =cut
